#include "hw_config.h"
#include "usb_lib.h"
#include "usb_pwr.h"

uint8_t MIDI_RecvBuff[64];
uint8_t MIDI_RecvLen;
uint8_t MIDI_SendBuff[64];
uint8_t MIDI_SendLen = 0;
volatile uint8_t RecvBufNE = 0;
volatile uint8_t USB_TC = 1;

static void uart_send(uint8_t *buf, uint8_t len)
{
	uint8_t i;
	
	USART_ClearFlag(USART1, USART_FLAG_TC);
	for(i = 0; i < len; i ++){
		USART_SendData(USART1, buf[i]);
		while(USART_GetFlagStatus(USART1, USART_FLAG_TC) == RESET);
	}
}

static void usb_send(uint8_t *buf, uint8_t len)
{
	while(!USB_TC);
	USB_TC = 0;
	USB_SIL_Write(ENDP1, buf, len);
	SetEPTxValid(ENDP1);
}

int main(void)
{
	uint8_t i, m, buff[4];
	
	Set_System();
	USB_Interrupts_Config();
	Set_USBClock();
	USB_Init();

	while(1){
		if(bDeviceState == CONFIGURED){
			/*****  UART->USB Routine  ***/
			if(MIDI_SendLen){
				if(MIDI_SendBuff[0] == 0xF0 && 
						MIDI_SendBuff[MIDI_SendLen - 1] == 0xF7){ /* SysEx */
					m = (MIDI_SendLen - 1) / 3;
					for(i = 0; i <= m; i ++){
						if(i == m)
							switch(MIDI_SendLen % 3){
								case 0: /* SysEx ends with following 3 bytes */
									buff[0] = 0x07;
									break;
								case 1: /* SysEx ends with following 1 bytes */
									buff[0] = 0x05;
									break;
								case 2: /* SysEx ends with following 2 bytes */
									buff[0] = 0x06;
									break;
							}
						else /* SysEx starts or continues */
							buff[0] = 0x04;
						buff[1] = MIDI_SendBuff[i * 3];
						buff[2] = MIDI_SendBuff[1 + i * 3];
						buff[3] = MIDI_SendBuff[2 + i * 3];
						usb_send(buff, 4);
					}
					for(i = 0; i < MIDI_SendLen; i ++)
						MIDI_SendBuff[i] = 0;
				}else /* General */
					switch(MIDI_SendBuff[0] & 0xF0){
						case 0xC0: /* Program Change */
						case 0xD0: /* Channel Change */
							if(MIDI_SendLen >= 2){
								buff[0] = MIDI_SendBuff[0] >> 4;
								buff[1] = MIDI_SendBuff[0];
								buff[2] = MIDI_SendBuff[1];
								buff[3] = 0;
								MIDI_SendLen = 0;
								usb_send(buff, 4);
							}
							break;
							
						case 0x80: /* Note-off */
						case 0x90: /* Note-on */
						case 0xA0: /* Poly-KeyPress */
						case 0xB0: /* Control Change */
						case 0xE0: /* PitchBend Change */
							if(MIDI_SendLen >= 3){
								buff[0] = MIDI_SendBuff[0] >> 4;
								buff[1] = MIDI_SendBuff[0];
								buff[2] = MIDI_SendBuff[1];
								buff[3] = MIDI_SendBuff[2];
								MIDI_SendLen = 0;
								usb_send(buff, 4);
							}
							break;
							
						default: MIDI_SendLen = 0;
					}
			}
			/***  USB->UART Routine  ***/
			if(RecvBufNE){
				i = 0;
				do
					switch(MIDI_RecvBuff[i]){
						case 0x05:
						case 0x0F:
							uart_send(&MIDI_RecvBuff[i + 1], 1);
							i += 2;
							break;
						
						case 0x06:
						case 0x0C:
						case 0x0D:
							uart_send(&MIDI_RecvBuff[i + 1], 2);
							i += 3;
							break;
						
						case 0x04:
						case 0x07:
						case 0x08:
						case 0x09:
						case 0x0A:
						case 0x0B:
						case 0x0E:
							uart_send(&MIDI_RecvBuff[i + 1], 3);
							i += 4;
							break;
						
						default: i ++; /* ignore 1 byte */
					}
				while(i < MIDI_RecvLen);
				RecvBufNE = 0;
			}
		}
	}
}
