/**
  ******************************************************************************
  * @file    usb_desc.c
  * @author  MCD Application Team
  * @version V3.4.0
  * @date    29-June-2012
  * @brief   Descriptors for Joystick Mouse Demo
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */


/* Includes ------------------------------------------------------------------*/
#include "usb_lib.h"
#include "usb_desc.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Extern variables ----------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/* USB Standard Device Descriptor */
const uint8_t Joystick_DeviceDescriptor[JOYSTICK_SIZ_DEVICE_DESC] = {
	0x12,                       /*bLength */
	USB_DEVICE_DESCRIPTOR_TYPE, /*bDescriptorType*/
	0x00,                       /*bcdUSB */
	0x02,
	0x00,                       /*bDeviceClass*/
	0x00,                       /*bDeviceSubClass*/
	0x00,                       /*bDeviceProtocol*/
	0x40,                       /*bMaxPacketSize 64*/
	0x83,                       /*idVendor = ST(0x0483)*/
	0x04,
	0x59,                       /*idProduct = 0x5259*/
	0x52,
	0x00,                       /*bcdDevice rel. 1.00*/
	0x01,
	1,                          /*Index of string descriptor describing
								  manufacturer */
	2,                          /*Index of string descriptor describing
								  product*/
	3,                          /*Index of string descriptor describing the
								  device serial number */
	0x01                        /*bNumConfigurations*/
};

/* USB Configuration Descriptor */
/* All Descriptors (Configuration, Interface, Endpoint, Class, Vendor */
const uint8_t Joystick_ConfigDescriptor[JOYSTICK_SIZ_CONFIG_DESC] = {
	0x09, /* bLength: Configuration Descriptor size */
	USB_CONFIGURATION_DESCRIPTOR_TYPE, /* bDescriptorType: Configuration */
	JOYSTICK_SIZ_CONFIG_DESC, /* wTotalLength: Bytes returned */
	0x00,
	0x02,         /*bNumInterfaces: 2 interface*/
	0x01,         /*bConfigurationValue: Configuration value*/
	0x00,         /*iConfiguration: Index of string descriptor describing
									 the configuration*/
	0x80,         /*bmAttributes: bus powered */
	0x32,         /*MaxPower 100 mA: this current is used for detecting Vbus*/
	/******************* Standard AC Interface Descriptor *********************/
	/* 09 */
	0x09,         /*bLength: Interface Descriptor size*/
	USB_INTERFACE_DESCRIPTOR_TYPE, /*bDescriptorType: Interface descriptor type*/
	0x00,         /*bInterfaceNumber: Number of Interface*/
	0x00,         /*bAlternateSetting: Alternate setting*/
	0x00,         /*bNumEndpoints*/
	0x01,         /*bInterfaceClass: Audio*/
	0x01,         /*bInterfaceSubClass : Audio Control*/
	0,            /*nInterfaceProtocol*/
	0,            /*iInterface: Index of string descriptor*/
	/**************** Class-specific AC Interface Descriptor ******************/
	/* 18 */
	0x09,         /*bLength: Interface Descriptor size*/
	0x24,         /*bDescriptorType: Class-specific interface descriptor type*/
	0x01,         /*bDescriptorSubType: Header*/
	0x00,         /*bcdADC: Revision of class specification - 1.0*/
	0x01,
	0x09,         /*wTotalLength: Total size of class specific discriptor*/
	0x00,
	0x01,         /*bInCollection: Number of streaming interfaces*/
	0x01,         /*baInterfaceNr : MIDIStreaming interface 1 belongs to 
	                                this AudioControl interface*/
	/******************* Standard MS Interface Descriptor *********************/
	/* 27 */
	0x09,         /*bLength: Interface Descriptor size*/
	USB_INTERFACE_DESCRIPTOR_TYPE, /*bDescriptorType: Interface descriptor type*/
	0x01,         /*bInterfaceNumber: Number of Interface*/
	0x00,         /*bAlternateSetting: Alternate setting*/
	0x02,         /*bNumEndpoints*/
	0x01,         /*bInterfaceClass: Audio*/
	0x03,         /*bInterfaceSubClass : MIDI Streaming*/
	0,            /*nInterfaceProtocol*/
	0,            /*iInterface: Index of string descriptor*/
	/**************** Class-specific MS Interface Descriptor ******************/
	/* 36 */
	0x07,         /*bLength: Interface Descriptor size*/
	0x24,         /*bDescriptorType: Class-specific interface descriptor type*/
	0x01,         /*bDescriptorSubType: MS Header*/
	0x00,         /*bcdADC: Revision of class specification*/
	0x01,
	0x41,         /*wTotalLength: Total size of class specific discriptor*/
	0x00,
	/******************* MIDI IN Jack Descriptor (Embedded) *******************/
	/* 43 */
	0x06,         /*bLength: Size of this descriptor*/
	0x24,         /*bDescriptorType: Class-specific interface descriptor type*/
	0x02,         /*bDescriptorSubType: MIDI IN Jack*/
	0x01,         /*bJackType: Embedded*/
	0x01,         /*bJackID: ID of this Jack*/
	0x00,         /*iJack*/
	/******************* MIDI IN Jack Descriptor (External) *******************/
	/* 49 */
	0x06,         /*bLength: Size of this descriptor*/
	0x24,         /*bDescriptorType: Class-specific interface descriptor type*/
	0x02,         /*bDescriptorSubType: MIDI IN Jack*/
	0x02,         /*bJackType: External*/
	0x02,         /*bJackID: ID of this Jack*/
	0x00,         /*iJack*/
	/******************* MIDI OUT Jack Descriptor (Embedded) ******************/
	/* 55 */
	0x09,         /*bLength: Size of this descriptor*/
	0x24,         /*bDescriptorType: Class-specific interface descriptor type*/
	0x03,         /*bDescriptorSubType: MIDI OUT Jack*/
	0x01,         /*bJackType: Embedded*/
	0x03,         /*bJackID: ID of this Jack*/
	0x01,         /*bNrInputPins: Number of Input Pins of this Jack*/
	0x02,         /*BaSourceID: ID of the Entry to which this Pin is connected*/
	0x01,         /*BaSourceID: Output Pin number of the Entry to 
	                            which this Input Pin is connected*/
	0x00,         /*iJack*/
	/******************* MIDI OUT Jack Descriptor (External) ******************/
	/* 64 */
	0x09,         /*bLength: Size of this descriptor*/
	0x24,         /*bDescriptorType: Class-specific interface descriptor type*/
	0x03,         /*bDescriptorSubType: MIDI OUT Jack*/
	0x02,         /*bJackType: External*/
	0x04,         /*bJackID: ID of this Jack*/
	0x01,         /*bNrInputPins: Number of Input Pins of this Jack*/
	0x01,         /*BaSourceID: ID of the Entry to which this Pin is connected*/
	0x01,         /*BaSourceID: Output Pin number of the Entry to 
	                            which this Input Pin is connected*/
	0x00,         /*iJack*/
	/****************** Standard Bulk OUT Endpoint Descriptor *****************/
	/* 73 */
	0x09,         /*bLength: Size of this descriptor*/
	USB_ENDPOINT_DESCRIPTOR_TYPE, /*bDescriptorType: Endpoint descriptor type*/
	0x01,         /*bEndpointAddress: OUT Endpoint 1*/
	0x02,         /*bmAttributes: Bulk, not shared.*/
	0x40,         /*wMaxPacketSize 64*/
	0x00,
	0x00,         /*bInterval*/
	0x00,         /*bRefresh*/
	0x00,         /*bSynchAddress*/
	/************* Class-specific MS Bulk OUT Endpoint Descriptor *************/
	/* 82 */
	0x05,         /*bLength: Size of this descriptor*/
	0x25,         /*bDescriptorType: Class-specific endpoint descriptor type*/
	0x01,         /*bDescriptorSubType: MS General*/
	0x01,         /*bNumEmbMIDIJack: Number of embedded MIDI IN Jack*/
	0x01,         /*BaAssocJackID: ID of the Embedded MIDI IN Jack*/
	/****************** Standard Bulk IN Endpoint Descriptor *****************/
	/* 87 */
	0x09,         /*bLength: Size of this descriptor*/
	USB_ENDPOINT_DESCRIPTOR_TYPE, /*bDescriptorType: Endpoint descriptor type*/
	0x81,         /*bEndpointAddress: IN Endpoint 1*/
	0x02,         /*bmAttributes: Bulk, not shared.*/
	0x40,         /*wMaxPacketSize 64*/
	0x00,
	0x00,         /*bInterval*/
	0x00,         /*bRefresh*/
	0x00,         /*bSynchAddress*/
	/************* Class-specific MS Bulk OUT Endpoint Descriptor *************/
	/* 96 */
	0x05,         /*bLength: Size of this descriptor*/
	0x25,         /*bDescriptorType: Class-specific endpoint descriptor type*/
	0x01,         /*bDescriptorSubType: MS General*/
	0x01,         /*bNumEmbMIDIJack: Number of embedded MIDI OUT Jack*/
	0x03,         /*BaAssocJackID: ID of the Embedded MIDI OUT Jack*/
	/* 101 */
};

const uint8_t Joystick_ReportDescriptor[JOYSTICK_SIZ_REPORT_DESC] = {
	0x05,          /*Usage Page(Generic Desktop)*/
	0x01,
	0x09,          /*Usage(Mouse)*/
	0x02,
	0xA1,          /*Collection(Logical)*/
	0x01,
	0x09,          /*Usage(Pointer)*/
	0x01,
	/* 8 */
	0xA1,          /*Collection(Linked)*/
	0x00,
	0x05,          /*Usage Page(Buttons)*/
	0x09,
	0x19,          /*Usage Minimum(1)*/
	0x01,
	0x29,          /*Usage Maximum(3)*/
	0x03,
	/* 16 */
	0x15,          /*Logical Minimum(0)*/
	0x00,
	0x25,          /*Logical Maximum(1)*/
	0x01,
	0x95,          /*Report Count(3)*/
	0x03,
	0x75,          /*Report Size(1)*/
	0x01,
	/* 24 */
	0x81,          /*Input(Variable)*/
	0x02,
	0x95,          /*Report Count(1)*/
	0x01,
	0x75,          /*Report Size(5)*/
	0x05,
	0x81,          /*Input(Constant,Array)*/
	0x01,
	/* 32 */
	0x05,          /*Usage Page(Generic Desktop)*/
	0x01,
	0x09,          /*Usage(X axis)*/
	0x30,
	0x09,          /*Usage(Y axis)*/
	0x31,
	0x09,          /*Usage(Wheel)*/
	0x38,
	/* 40 */
	0x15,          /*Logical Minimum(-127)*/
	0x81,
	0x25,          /*Logical Maximum(127)*/
	0x7F,
	0x75,          /*Report Size(8)*/
	0x08,
	0x95,          /*Report Count(3)*/
	0x03,
	/* 48 */
	0x81,          /*Input(Variable, Relative)*/
	0x06,
	0xC0,          /*End Collection*/
	0x09,
	0x3c,
	0x05,
	0xff,
	0x09,
	/* 56 */
	0x01,
	0x15,
	0x00,
	0x25,
	0x01,
	0x75,
	0x01,
	0x95,
	/* 64 */
	0x02,
	0xb1,
	0x22,
	0x75,
	0x06,
	0x95,
	0x01,
	0xb1,
	/* 72 */
	0x01,
	0xc0
};

/* USB String Descriptors (optional) */
const uint8_t Joystick_StringLangID[JOYSTICK_SIZ_STRING_LANGID] =
  {
    JOYSTICK_SIZ_STRING_LANGID,
    USB_STRING_DESCRIPTOR_TYPE,
    0x09,
    0x04
  }
  ; /* LangID = 0x0409: U.S. English */

const uint8_t Joystick_StringVendor[JOYSTICK_SIZ_STRING_VENDOR] = {
	JOYSTICK_SIZ_STRING_VENDOR, /* Size of Vendor string */
	USB_STRING_DESCRIPTOR_TYPE,  /* bDescriptorType*/
	/* Manufacturer: "Syllament" */
	'S', 0, 'y', 0, 'l', 0, 'l', 0, 'a', 0, 'm', 0, 'e', 0, 'n', 0,
	't', 0,
};

const uint8_t Joystick_StringProduct[JOYSTICK_SIZ_STRING_PRODUCT] = {
	JOYSTICK_SIZ_STRING_PRODUCT,          /* bLength */
	USB_STRING_DESCRIPTOR_TYPE,        /* bDescriptorType */
	'S', 0, 'i', 0, 'm', 0, 'p', 0, 'l', 0, 'e', 0, ' ', 0,
	'M', 0, 'I', 0, 'D', 0, 'I', 0, ' ', 0, 'A', 0, 'd', 0,
	'a', 0, 'p', 0, 't', 0, 'e', 0, 'r', 0,
};

uint8_t Joystick_StringSerial[JOYSTICK_SIZ_STRING_SERIAL] = {
	JOYSTICK_SIZ_STRING_SERIAL,           /* bLength */
	USB_STRING_DESCRIPTOR_TYPE,        /* bDescriptorType */
	'S', 0, 'T', 0,
};

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/

